# Changelog

*v1.1.0:*

- Fix the bug where log level colors were ignored if `no_color_tags` flag was set (by Tamika Nomara)
- Add `yuio.exec` module (by Tamika Nomara)
- Add more options for displaying task progress (by Tamika Nomara)

*v1.0.1:*

- Update trove classifiers for project status: stable.

*v1.0.0:*

- Initial release.
